@@ -30,14 +30,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "pythread.h"
 #endif
 
-static char __authors__[] =
+static char __author__[] =
 "The mcrypt python module was developed by:\n\
 \n\
     Gustavo Niemeyer <niemeyer@conectiva.com>\n\
-\n\
-The mcrypt library was developed by:\n\
-\n\
-    Nikos Mavroyanopoulos <nmav@hellug.gr>\n\
 ";
 
 static PyObject *MCRYPTError;
@@ -1126,16 +1122,14 @@ Constructor\n\
 \n\
 MCRYPT(algorithm, mode [, algorithm_dir, mode_dir])\n\
 \n\
-The first parameter is one of the MCRYPT_* algorithm constants provided in\n\
-the mcrypt module. This will select the cryptography algorithm you want to\n\
-use. The second parameter is one of the MCRYPT_* mode constants provided in\n\
-the mcrypt module, and will select the cryptography mode you want to use.\n\
-The third and fourth parameters are used to select the directory where the\n\
-mcrypt library will look for the respective modules. You usually won't have\n\
-to set these, and if you have to, you may want to use the\n\
-set_algorithm_dir() and set_mode_dir() functions provided in the mcrypt\n
-module, so you won't have to set these everytime you instantiate an MCRYPT\n\
-object.\n\
+The first parameter is a string containing the name of a known cryptography\n\
+algorithm. The second parameter is a string containing the name of a known\n\
+cryptography mode. The third and fourth parameters are used to select the\n\
+directory where the mcrypt library will look for the respective modules.\n\
+You usually won't have to set these, and if you have to, you may want to\n\
+use the set_algorithm_dir() and set_mode_dir() functions provided in the\n\
+mcrypt module, so you won't have to set these everytime you instantiate\n\
+an MCRYPT object.\n\
 \n\
 \n\
 Methods\n\
@@ -1170,7 +1164,7 @@ mode        - Selected mode.\n\
 statichere PyTypeObject MCRYPT_Type = {
 	PyObject_HEAD_INIT(NULL)
 	0,			/*ob_size*/
-	"MCRYPT",		/*tp_name*/
+	"mcrypt.MCRYPT",	/*tp_name*/
 	sizeof(MCRYPTObject),	/*tp_basicsize*/
 	0,			/*tp_itemsize*/
 	(destructor)MCRYPT_dealloc, /*tp_dealloc*/
@@ -1675,7 +1669,7 @@ Classes\n\
 -------\n\
 \n\
 Instances of this class, or subclasses of it, may be used to encyrpt\n\
-and decrypt strings and files. This is a newstyle class, and thys may be\n
+and decrypt strings and files. This is a newstyle class, and thys may be\n\
 subclassed by python classes.\n\
 \n\
 MCRYPT(algorithm, mode [, algorithm_dir, mode_dir])\n\
@@ -1716,7 +1710,7 @@ initmcrypt(void)
 
 	m = Py_InitModule3("mcrypt", mcrypt_methods, mcrypt__doc__);
 
-	PyModule_AddObject(m, "__authors__", PyString_FromString(__authors__));
+	PyModule_AddObject(m, "__author__", PyString_FromString(__author__));
 	PyModule_AddObject(m, "__version__", PyString_FromString(VERSION));
 
 	Py_INCREF(&MCRYPT_Type);
